
class Stack():
	def __init__(self):
		self.stack_list = []

	def push(self, element):
		self.stack_list.append(element)

	def pop(self):
		try:
			return self.stack_list.pop(-1)
		except IndexError as e:
			raise EmptyStackException("Stack is empty, can't pop")
		
	def clear(self):
		del self.stack_list[:]

	def display(self):
		print(self.stack_list)

	def search(self, element):
		index_of_element = -1
		for i in range(self.get_stack_size()):
			if(self.stack_list[i] == element):
				index_of_element = i
		return index_of_element

	def is_empty(self):
		return not self.stack_list

	def clone(self):
		return self.stack_list.copy()

	def peek(self):
		try:	
			return self.stack_list[-1]
		except IndexError as e:
			raise EmptyStackException("May stack is empty")
		
		

	def get_stack_size(self):
		return len(self.stack_list)


class EmptyStackException(Exception):

	def __init__(self, *args):
		if args:
			self.message = args[0]
		else:
			self.message = None

	def __str__(self):
		if self.message:
			message =  'Exception: {0} '.format(self.message)
		else:
			message =  'Check stack, May be empty'
		return message


#Uni testing
from Stack import Stack

def test_stack_push_integer():
	stack = Stack()
	input_value = 5
	stack.push(input_value)
	assert stack.peek() == input_value

def test_stack_push_string():
	stack = Stack()
	input_value = "Element"
	stack.push(input_value)
	assert stack.peek() == input_value

def test_stack_push_float():
	stack = Stack()
	input_value = 3.2
	stack.push(input_value)
	assert stack.peek() == input_value

def test_stack_push_boolean():
	stack = Stack()
	input_value = True
	stack.push(input_value)
	assert stack.peek() == input_value



from setuptools import setup

with open('py_datastructures/README.md') as f:
    long_description = f.read()

setup(name='py_datastructures',
      version='0.1.1',
      description='Data Structures using Python',
      packages=['py_datastructures'],
      author = 'Adithya Yelloju',
      author_email = 'adithyayelloju@gmail.com',
      long_description = long_description,
      long_description_content_type="text/markdown",
      url='https://github.com/AdithyaYelloju/Data-Structures-in-Python',
      zip_safe=False)
